pub struct LlmConfig {
pub provider: String,
pub base_url: String,
pub api_key: String,
pub model: String,
pub temperature: f32,
pub max_tokens: u32,
pub enable_vision: bool,
}Fields
provider: Stringbase_url: Stringapi_key: Stringmodel: Stringtemperature: f32max_tokens: u32enable_vision: boolWhen true, image messages are sent to the LLM to produce text descriptions that are then stored as memory content.